import { Injectable } from "@angular/core";
import { SwUpdate } from '@angular/service-worker';
import { I18nService } from "./internationalisation.service";
import { NotificationsService } from "./notifications.service";

@Injectable()
export class ServiceWorkerUpdateService {
    constructor(
        private swUpdate: SwUpdate,
        private notificationService: NotificationsService,
        private i18nService: I18nService
    ) {
        swUpdate.versionUpdates.subscribe(evt => {
            switch (evt.type) {
                case 'VERSION_DETECTED':
                    let ver = evt.version.appData["version"];
                    let msg = i18nService.localizeText("INFO_SERVICE_WORKER_VERSION_DETECTED", { "ver": ver });
                    notificationService.notify(msg, 10000);
                    break;

                case 'VERSION_READY':
                    const newVer = evt.latestVersion.appData["version"];
                    // const currVer = evt.currentVersion.appData["version"];
                    msg = i18nService.localizeText("INFO_SERVICE_WORKER_VERSION_READY", { "ver": newVer });
                    notificationService.notify(msg, 10000);
                    break;

                case 'VERSION_INSTALLATION_FAILED':
                    ver = evt.version.appData["version"];
                    msg = i18nService.localizeText("ERROR_SERVICE_WORKER_INSTALL_FAILED", { "ver": ver });
                    notificationService.notify(msg, 10000);
                    break;
            }
        });
        swUpdate.unrecoverable.subscribe(event => {
            notificationService.notify("SwUpdate: unrecoverable state. Reason=" + event.reason + ", type=" + event.type, 10000);
        });
    }
}
